/**************************************************************************
*  Copyright (c) 2016 by Michael Fischer (www.emb4fun.de).
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  03.04.2016  mifi  First Version.
**************************************************************************/
#define __TALMEM_NUTNET_C__

/*=======================================================================*/
/*  Include                                                              */
/*=======================================================================*/
#include <stdint.h>
#include <string.h>
#include "tal.h"

#include "sys/heap.h"

/*=======================================================================*/
/*  All Structures and Common Constants                                  */
/*=======================================================================*/

/*
 * Configure external memory for the HEAP
 */
#define TAL_HEAP_MEM1_START   __RAM_segment_used_end__
#define TAL_HEAP_MEM1_END     __RAM_segment_end__

#if !defined(_RUN_FROM_EXTRAM)   /* Defined by the Preprocessor */
#define TAL_HEAP_MEM2_START   __External_SRAM_segment_start__
#define TAL_HEAP_MEM2_END     __External_SRAM_segment_end__
#else
#define TAL_HEAP_MEM2_START   __External_SRAM_segment_used_end__
#define TAL_HEAP_MEM2_END     __External_SRAM_segment_end__
#endif

extern uint32_t TAL_HEAP_MEM1_START;
extern uint32_t TAL_HEAP_MEM1_END;

extern uint32_t TAL_HEAP_MEM2_START;
extern uint32_t TAL_HEAP_MEM2_END;  

#define HEAP_START  &TAL_HEAP_MEM2_START
#define HEAP_SIZE  ((uintptr_t)(&TAL_HEAP_MEM2_END - 1) - (uintptr_t)(HEAP_START) - 256)

/*=======================================================================*/
/*  Definition of all local Data                                         */
/*=======================================================================*/

/*=======================================================================*/
/*  Definition of all local Procedures                                   */
/*=======================================================================*/

/*=======================================================================*/
/*  All code exported                                                    */
/*=======================================================================*/

/*************************************************************************/
/*  tal_BoardMemInit                                                     */
/*                                                                       */
/*  In    : none                                                         */
/*  Out   : none                                                         */
/*  Return: none                                                         */
/*************************************************************************/
void tal_BoardMemInit (void)
{
   /* Initialize our heap memory. */
   NutHeapAdd(HEAP_START, HEAP_SIZE & ~3);   /*lint !e428*/
} /* tal_BoardMemInit */

/*** EOF ***/
